BridgeProtocol class
Serializes commands to send from Flutter to the WebView bridge.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
close(
) → String -
initCommand(
Map< String, dynamic> config) → String -
openConversation(
String ticketId) → String -
openConversations(
) → String -
openHelpCenter(
{String? slug, String? path, String? tenantSlug, String? appSlug, String? articleId, String? locale}) → String -
openNewConversation(
{String? subject, String? conversationPrefillText, String? initialUserMessage, Map< String, dynamic> ? customFields, List<String> ? tags}) → String -
setCustomFields(
Map< String, dynamic> fields) → String -
setDeviceInfo(
Map< String, dynamic> device) → String -
setTags(
List< String> tags) → String -
setUser(
Map< String, dynamic> user) → String