SupportPortalUser class

Represents an identified end-user for the Support Portal.

Constructors

SupportPortalUser({required String externalId, String? name, String? email, String? avatar, Map<String, dynamic>? metadata})
const

Properties

avatar → String?
final
email → String?
final
externalId → String
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited