SupportPortalConfig class
Configuration for the Support Portal SDK.
Constructors
Properties
- apiUrl → String
-
final
- appId → String
-
final
- domain → String
-
final
- enableDebugLogging → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpCenterUrl → String?
-
final
- maxOpenTickets → int
-
final
- platformId → String
-
final
- primaryColor → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → String?
-
final
- welcomeMessage → String?
-
final
- wsUrl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited