SupportPortalView class
Widget that hosts the embedded web SDK inside a WebView.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SupportPortalView
Constructors
-
SupportPortalView({Key? key, String mode = 'conversations', String? ticketId, String? subject, String? conversationPrefillText, String? initialUserMessage, String? helpSlug, String? helpPath, String? helpTenantSlug, String? helpAppSlug, String? helpArticleId, String? helpLocale, void onEvent(Map<
String, dynamic> event)?, VoidCallback? onClose}) -
const
Properties
- conversationPrefillText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpAppSlug → String?
-
final
- helpArticleId → String?
-
final
- helpLocale → String?
-
final
- helpPath → String?
-
final
- helpSlug → String?
-
final
- helpTenantSlug → String?
-
final
- initialUserMessage → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mode → String
-
final
- onClose → VoidCallback?
-
final
-
onEvent
→ void Function(Map<
String, dynamic> event)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String?
-
final
- ticketId → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SupportPortalView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited